# python-sphinx

[![pypi](https://img.shields.io/pypi/v/steenzout.sphinx.svg)](https://pypi.python.org/pypi/steenzout.sphinx/)
[![Build Status](https://travis-ci.org/steenzout/python-sphinx.svg?branch=master)](https://travis-ci.org/steenzout/python-sphinx)
[![Code Health](https://landscape.io/github/steenzout/python-sphinx/master/landscape.svg?style=flat)](https://landscape.io/github/steenzout/python-sphinx/master)
[![Coverage Status](https://coveralls.io/repos/github/steenzout/python-sphinx/badge.svg?branch=master)](https://coveralls.io/r/steenzout/python-sphinx)
[![Requirements Status](https://requires.io/github/steenzout/python-sphinx/requirements.svg?branch=master)](https://requires.io/github/steenzout/python-sphinx/requirements/?branch=master)
[![Documentation Status](https://readthedocs.org/projects/python-steenzout-sphinx/badge/?version=latest)](http://python-steenzout-sphinx.readthedocs.io/en/latest/?badge=latest)

[![License](https://img.shields.io/badge/license-Apache%20License%202.0-blue.svg?style=flat)][license]
[![Project Stats](https://www.openhub.net/p/python-steenzout-sphinx/widgets/project_thin_badge.gif)](https://www.openhub.net/p/python-steenzout-sphinx/)

Package to help produce and maintain Sphinx configuration and Makefile templates.


[license]:  https://raw.githubusercontent.com/steenzout/python-sphinx/master/LICENSE    "License"
